==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/HorizontalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var HorizontalStackedSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HorizontalStackedSeriesBaseDescriptionMetadata, _super);
    function HorizontalStackedSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalStackedSeriesBaseDescriptionMetadata.b = function (a) {
        if (HorizontalStackedSeriesBaseDescriptionMetadata.a == null) {
            HorizontalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HorizontalStackedSeriesBaseDescriptionMetadata.c(HorizontalStackedSeriesBaseDescriptionMetadata.a);
        }
        if (a.g(HorizontalStackedSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(HorizontalStackedSeriesBaseDescriptionMetadata.a);
    };
    HorizontalStackedSeriesBaseDescriptionMetadata.c = function (a) {
        StackedSeriesBaseDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    HorizontalStackedSeriesBaseDescriptionMetadata.d = function (a) {
        HorizontalStackedSeriesBaseDescriptionMetadata.b(a);
        a.t("HorizontalStackedSeriesBase", HorizontalStackedSeriesBaseDescriptionMetadata.a);
    };
    HorizontalStackedSeriesBaseDescriptionMetadata.$t = markType(HorizontalStackedSeriesBaseDescriptionMetadata, 'HorizontalStackedSeriesBaseDescriptionMetadata');
    HorizontalStackedSeriesBaseDescriptionMetadata.a = null;
    return HorizontalStackedSeriesBaseDescriptionMetadata;
}(Base));
export { HorizontalStackedSeriesBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/HorizontalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var HorizontalStackedSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HorizontalStackedSeriesBaseDescriptionMetadata, _super);
    function HorizontalStackedSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalStackedSeriesBaseDescriptionMetadata.b = function (a) {
        if (HorizontalStackedSeriesBaseDescriptionMetadata.a == null) {
            HorizontalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HorizontalStackedSeriesBaseDescriptionMetadata.c(HorizontalStackedSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(HorizontalStackedSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(HorizontalStackedSeriesBaseDescriptionMetadata.a);
    };
    HorizontalStackedSeriesBaseDescriptionMetadata.c = function (a) {
        StackedSeriesBaseDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    HorizontalStackedSeriesBaseDescriptionMetadata.d = function (a) {
        HorizontalStackedSeriesBaseDescriptionMetadata.b(a);
        a.z("HorizontalStackedSeriesBase", HorizontalStackedSeriesBaseDescriptionMetadata.a);
    };
    HorizontalStackedSeriesBaseDescriptionMetadata.$t = markType(HorizontalStackedSeriesBaseDescriptionMetadata, 'HorizontalStackedSeriesBaseDescriptionMetadata');
    HorizontalStackedSeriesBaseDescriptionMetadata.a = null;
    return HorizontalStackedSeriesBaseDescriptionMetadata;
}(Base));
export { HorizontalStackedSeriesBaseDescriptionMetadata };
